@@ -1,37 +1,33 @@
-import { render, waitFor } from '@testing-library/react';
-import React from 'react';
-import { TestProvider } from 'test/helpers/TestProvider';
-import { byTestId } from 'testing-library-selector';
+import { render } from 'test/test-utils';
+import { byTestId, byText } from 'testing-library-selector';
 
 import { DataSourceApi } from '@grafana/data';
-import { setDataSourceSrv } from '@grafana/runtime';
+import { PromOptions, PrometheusDatasource } from '@grafana/prometheus';
+import { setDataSourceSrv, setPluginExtensionsHook } from '@grafana/runtime';
 import * as ruleActionButtons from 'app/features/alerting/unified/components/rules/RuleActionsButtons';
 import { DashboardModel, PanelModel } from 'app/features/dashboard/state';
 import { getDatasourceSrv } from 'app/features/plugins/datasource_srv';
-import { toggleOption } from 'app/features/variables/pickers/OptionsPicker/reducer';
-import { toKeyedAction } from 'app/features/variables/state/keyedVariablesReducer';
-import { PrometheusDatasource } from 'app/plugins/datasource/prometheus/datasource';
-import { PromOptions } from 'app/plugins/datasource/prometheus/types';
-import { configureStore } from 'app/store/configureStore';
-import { AlertQuery } from 'app/types/unified-alerting-dto';
+import { AccessControlAction } from 'app/types';
+import { AlertQuery, PromRulesResponse } from 'app/types/unified-alerting-dto';
 
 import { PanelAlertTabContent } from './PanelAlertTabContent';
-import { fetchRules } from './api/prometheus';
-import { fetchRulerRules } from './api/ruler';
+import * as apiRuler from './api/ruler';
+import * as alertingAbilities from './hooks/useAbilities';
+import { mockAlertRuleApi, setupMswServer } from './mockApi';
 import {
-  disableRBAC,
-  mockDataSource,
   MockDataSourceSrv,
+  grantUserPermissions,
+  mockDataSource,
+  mockPromAlert,
   mockPromAlertingRule,
-  mockPromRuleGroup,
-  mockPromRuleNamespace,
-  mockRulerGrafanaRule,
+  mockRulerAlertingRule,
+  mockRulerRuleGroup,
 } from './mocks';
+import { captureRequests } from './mocks/server/events';
 import { RuleFormValues } from './types/rule-form';
 import * as config from './utils/config';
 import { Annotation } from './utils/constants';
 import { DataSourceType, GRAFANA_RULES_SOURCE_NAME } from './utils/datasource';
-import * as ruleFormUtils from './utils/rule-form';
 
 jest.mock('./api/prometheus');
 jest.mock('./api/ruler');
@@ -39,7 +35,8 @@ jest.mock('../../../core/hooks/useMediaQueryChange');
 
 jest.spyOn(config, 'getAllDataSources');
 jest.spyOn(ruleActionButtons, 'matchesWidth').mockReturnValue(false);
-
+jest.spyOn(apiRuler, 'rulerUrlBuilder');
+jest.spyOn(alertingAbilities, 'useAlertRuleAbility');
 const dataSources = {
   prometheus: mockDataSource<PromOptions>({
     name: 'Prometheus',
@@ -57,88 +54,90 @@ dataSources.default.meta.alerting = true;
 
 const mocks = {
   getAllDataSources: jest.mocked(config.getAllDataSources),
-  api: {
-    fetchRules: jest.mocked(fetchRules),
-    fetchRulerRules: jest.mocked(fetchRulerRules),
-  },
+  useAlertRuleAbilityMock: jest.mocked(alertingAbilities.useAlertRuleAbility),
+  rulerBuilderMock: jest.mocked(apiRuler.rulerUrlBuilder),
 };
 
-const renderAlertTabContent = (
-  dashboard: DashboardModel,
-  panel: PanelModel,
-  initialStore?: ReturnType<typeof configureStore>
-) => {
-  render(
-    <TestProvider store={initialStore}>
-      <PanelAlertTabContent dashboard={dashboard} panel={panel} />
-    </TestProvider>
-  );
+const renderAlertTabContent = (dashboard: DashboardModel, panel: PanelModel) => {
+  render(<PanelAlertTabContent dashboard={dashboard} panel={panel} />);
 };
 
-const rules = [
-  mockPromRuleNamespace({
-    name: 'default',
+const promResponse: PromRulesResponse = {
+  status: 'success',
+  data: {
     groups: [
-      mockPromRuleGroup({
+      {
         name: 'mygroup',
+        file: 'default',
         rules: [
           mockPromAlertingRule({
             name: 'dashboardrule1',
-            annotations: {
-              [Annotation.dashboardUID]: '12',
-              [Annotation.panelID]: '34',
-            },
+            alerts: [
+              mockPromAlert({
+                labels: { severity: 'critical' },
+                annotations: {
+                  [Annotation.dashboardUID]: '12',
+                  [Annotation.panelID]: '34',
+                },
+              }),
+            ],
+            totals: { alerting: 1 },
+            totalsFiltered: { alerting: 1 },
           }),
         ],
-      }),
-      mockPromRuleGroup({
+        interval: 20,
+      },
+      {
         name: 'othergroup',
+        file: 'default',
         rules: [
           mockPromAlertingRule({
             name: 'dashboardrule2',
-            annotations: {
-              [Annotation.dashboardUID]: '121',
-              [Annotation.panelID]: '341',
-            },
+            alerts: [
+              mockPromAlert({
+                labels: { severity: 'critical' },
+                annotations: {
+                  [Annotation.dashboardUID]: '121',
+                  [Annotation.panelID]: '341',
+                },
+              }),
+            ],
+            totals: { alerting: 1 },
+            totalsFiltered: { alerting: 1 },
           }),
         ],
-      }),
+        interval: 20,
+      },
     ],
-  }),
-];
-
-const rulerRules = {
+    totals: {
+      alerting: 2,
+    },
+  },
+};
+const rulerResponse = {
   default: [
-    {
+    mockRulerRuleGroup({
       name: 'mygroup',
       rules: [
-        mockRulerGrafanaRule(
-          {
-            annotations: {
-              [Annotation.dashboardUID]: '12',
-              [Annotation.panelID]: '34',
-            },
+        mockRulerAlertingRule({
+          alert: 'dashboardrule1',
+          annotations: {
+            [Annotation.dashboardUID]: '12',
+            [Annotation.panelID]: '34',
           },
-          {
-            title: 'dashboardrule1',
-          }
-        ),
+        }),
       ],
-    },
+    }),
     {
       name: 'othergroup',
       rules: [
-        mockRulerGrafanaRule(
-          {
-            annotations: {
-              [Annotation.dashboardUID]: '121',
-              [Annotation.panelID]: '341',
-            },
+        mockRulerAlertingRule({
+          alert: 'dashboardrule2',
+          annotations: {
+            [Annotation.dashboardUID]: '121',
+            [Annotation.panelID]: '341',
           },
-          {
-            title: 'dashboardrule2',
-          }
-        ),
+        }),
       ],
     },
   ],
@@ -152,7 +151,7 @@ const dashboard = {
   },
   meta: {
     canSave: true,
-    folderId: 1,
+    folderUid: 'abc',
     folderTitle: 'super folder',
   },
 } as DashboardModel;
@@ -175,22 +174,44 @@ const panel = new PanelModel({
 const ui = {
   row: byTestId('row'),
   createButton: byTestId<HTMLAnchorElement>('create-alert-rule-button'),
+  notSavedYet: byText('Dashboard not saved'),
 };
 
+const server = setupMswServer();
+
 describe('PanelAlertTabContent', () => {
   beforeEach(() => {
     jest.resetAllMocks();
+    grantUserPermissions([
+      AccessControlAction.AlertingRuleRead,
+      AccessControlAction.AlertingRuleUpdate,
+      AccessControlAction.AlertingRuleDelete,
+      AccessControlAction.AlertingRuleCreate,
+      AccessControlAction.AlertingRuleExternalRead,
+      AccessControlAction.AlertingRuleExternalWrite,
+    ]);
+
+    setPluginExtensionsHook(() => ({
+      extensions: [],
+      isLoading: false,
+    }));
+
     mocks.getAllDataSources.mockReturnValue(Object.values(dataSources));
     const dsService = new MockDataSourceSrv(dataSources);
     dsService.datasources[dataSources.prometheus.uid] = new PrometheusDatasource(
       dataSources.prometheus
-    ) as DataSourceApi<any, any>;
-    dsService.datasources[dataSources.default.uid] = new PrometheusDatasource(dataSources.default) as DataSourceApi<
-      any,
-      any
-    >;
+    ) as DataSourceApi;
+    dsService.datasources[dataSources.default.uid] = new PrometheusDatasource(dataSources.default) as DataSourceApi;
     setDataSourceSrv(dsService);
-    disableRBAC();
+    mocks.rulerBuilderMock.mockReturnValue({
+      rules: () => ({ path: `api/ruler/${GRAFANA_RULES_SOURCE_NAME}/api/v1/rules` }),
+      namespace: () => ({ path: 'ruler' }),
+      namespaceGroup: () => ({ path: 'ruler' }),
+    });
+    mocks.useAlertRuleAbilityMock.mockReturnValue([true, true]);
+
+    mockAlertRuleApi(server).prometheusRuleNamespaces(GRAFANA_RULES_SOURCE_NAME, promResponse);
+    mockAlertRuleApi(server).rulerRules(GRAFANA_RULES_SOURCE_NAME, rulerResponse);
   });
 
   it('Will take into account panel maxDataPoints', async () => {
@@ -252,6 +273,29 @@ describe('PanelAlertTabContent', () => {
     });
   });
 
+  it('should not make requests for unsaved dashboard', async () => {
+    const capture = captureRequests();
+
+    const unsavedDashboard = {
+      ...dashboard,
+      uid: null,
+    } as DashboardModel;
+
+    renderAlertTabContent(
+      unsavedDashboard,
+      new PanelModel({
+        ...panel,
+        datasource: undefined,
+        maxDataPoints: 100,
+        interval: '10s',
+      })
+    );
+
+    expect(await ui.notSavedYet.find()).toBeInTheDocument();
+    const requests = await capture;
+    expect(requests.length).toBe(0);
+  });
+
   it('Will take into account datasource minInterval', async () => {
     (getDatasourceSrv() as unknown as MockDataSourceSrv).datasources[dataSources.prometheus.uid].interval = '7m';
 
@@ -283,13 +327,11 @@ describe('PanelAlertTabContent', () => {
   });
 
   it('Will render alerts belonging to panel and a button to create alert from panel queries', async () => {
-    mocks.api.fetchRules.mockResolvedValue(rules);
-    mocks.api.fetchRulerRules.mockResolvedValue(rulerRules);
-
     renderAlertTabContent(dashboard, panel);
 
     const rows = await ui.row.findAll();
-    expect(rows).toHaveLength(1);
+    // after updating to RTKQ, the response is already returning the alerts belonging to the panel
+    expect(rows).toHaveLength(2);
     expect(rows[0]).toHaveTextContent(/dashboardrule1/);
     expect(rows[0]).not.toHaveTextContent(/dashboardrule2/);
 
@@ -311,37 +353,5 @@ describe('PanelAlertTabContent', () => {
     };
 
     expect(defaultsWithDeterministicTime).toMatchSnapshot();
-
-    expect(mocks.api.fetchRulerRules).toHaveBeenCalledWith(
-      { dataSourceName: GRAFANA_RULES_SOURCE_NAME, apiVersion: 'legacy' },
-      {
-        dashboardUID: dashboard.uid,
-        panelId: panel.id,
-      }
-    );
-    expect(mocks.api.fetchRules).toHaveBeenCalledWith(GRAFANA_RULES_SOURCE_NAME, {
-      dashboardUID: dashboard.uid,
-      panelId: panel.id,
-    });
-  });
-
-  it('Update NewRuleFromPanel button url when template changes', async () => {
-    const panelToRuleValuesSpy = jest.spyOn(ruleFormUtils, 'panelToRuleFormValues');
-
-    const store = configureStore();
-    renderAlertTabContent(dashboard, panel, store);
-
-    store.dispatch(
-      toKeyedAction(
-        'optionKey',
-        toggleOption({
-          option: { value: 'optionValue', selected: true, text: 'Option' },
-          clearOthers: false,
-          forceSelect: false,
-        })
-      )
-    );
-
-    await waitFor(() => expect(panelToRuleValuesSpy).toHaveBeenCalledTimes(2));
   });
 });
